%% Plots highlighting the link between fast-scale entropy and PSD slope

load('/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/A_MSE_CSD_multiVariant/B_data/E_mseMerged.mat', 'mseMerged', 'IDs')
% add convertPtoExponential
addpath('/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/A_MSE_CSD_multiVariant/T_tools/')
pn.shadedError = ['/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/A_MSE_CSD_multiVariant/T_tools/shadedErrorBar']; addpath(pn.shadedError);
indCond = 2; channels = 1:60;
load('/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/B_FFT/B_data/B_FFT_grandavg_individual.mat')
commonYA = info.IDs_all(ismember(info.IDs_all, IDs{1}));
commonOA = info.IDs_all(ismember(info.IDs_all, IDs{2}));
idx_YA_fft = ismember(info.IDs_all, commonYA);
idx_OA_fft = ismember(info.IDs_all, commonOA);
idx_YA_mse = ismember(IDs{1}, commonYA);
idx_OA_mse = ismember(IDs{2}, commonOA);
load('/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/B_FFT/B_data/D_PSDslopes.mat')

%% fast MSE-PSD slope correlation

h = figure('units','normalized','position',[.1 .1 .3 .3]);

%% superimpose correlation coefficients by time scale

channels = 43:60; % parieto-occipital channels

labels = {'MSEVanilla'; 'MSEfiltskip'; 'MSEhp'; 'MSEbp'};
scales = {[1]; [5:10]};

labelTitle = {'Original'; 'Low-pass'; 'High-pass'; 'Band-pass'};
scaleTitle = {'1'; '5-10'};

for indLabel = 1:3
    %subplot(1,3,indLabel); cla; hold on;
        hold on;
        for indScale = 1:41
            %cla; hold on;
            x = squeeze(nanmean(nanmean(mseMerged{1,indCond}.(labels{indLabel})(idx_YA_mse,channels,indScale),3),2));
            y = squeeze(nanmean(linFit_2_30_EO(idx_YA_fft, channels),2));
            [rl1,pl1] = corrcoef(x,y);
            Rmat(1,indScale) = rl1(2);
            Pmat(1,indScale) = pl1(2);
            % add OA
            x = squeeze(nanmean(nanmean(mseMerged{2,indCond}.(labels{indLabel})(idx_OA_mse,channels,indScale),3),2));
            y = squeeze(nanmean(linFit_2_30_EO(idx_OA_fft, channels),2));
            [rl2,pl2] = corrcoef(x,y);
            Rmat(2,indScale) = rl2(2);
            Pmat(2,indScale) = pl2(2);
        end
        if indLabel == 1
            lineStyle = '-';
        elseif indLabel == 2
            lineStyle = '--';
        elseif indLabel == 3
            lineStyle = ':';
        end
        ll{indLabel,1} = plot(Rmat(1,:), 'LineWidth', 3, 'Color', 'k', 'LineStyle', lineStyle)
        ll{indLabel,2} = plot(Rmat(2,:), 'LineWidth', 3, 'Color', 'r', 'LineStyle', lineStyle)
        xlim([1 41]); ylim([-1 1])
        set(gca, 'XScale', 'log')
        scales = 1:41;
        set(gca, 'XTick',round(logspace(log10(1), log10(41), 5)));
        tmp_meas = [round(mseMerged{1,indCond}.freq(get(gca, 'XTick')),0); round(scales(get(gca, 'XTick')),0)];
        xLabels = [];
        for indScale = 1:size(tmp_meas,2)
            xLabels{indScale} = [num2str(tmp_meas(1,indScale)), '/',num2str(tmp_meas(2,indScale))];
        end; clear tmp_meas;
        set(gca, 'XTickLabels', xLabels);
%             set(gca, 'XDir','reverse')
end
xlabel('Time scale [Hz/scale-factor; log-scaled]'); ylabel('Correlation coefficient (r)')
title({'Correlation with PSD slope depends on filter & criterion choice'; ''})
lgd1 = legend([ll{1,1}, ll{2,1}, ll{3,1}], ...
    {'YA: Original', 'YA: low-pass', 'YA: high-pass'}, ...
    'location', 'SouthWest'); legend('boxoff');
ah1=axes('position',get(gca,'position'),'visible','off');

lgd2 = legend(ah1,[ll{1,2},ll{2,2},ll{3,2}], ...
    {'OA: Original', 'OA: low-pass', 'OA: high-pass'}, ...
    'location', 'South'); legend('boxoff');
set(findall(gcf,'-property','FontSize'),'FontSize',22)

set(lgd1,'FontSize',18)
set(lgd2,'FontSize',18)

pn.plotFolder = '/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/A_MSE_CSD_multiVariant/C_figures/';
figureName = 'F4_FastScalePSDassociation_byMethod_CorrelationOnly';
saveas(h, [pn.plotFolder, figureName], 'fig');
saveas(h, [pn.plotFolder, figureName], 'epsc');
saveas(h, [pn.plotFolder, figureName], 'png');

%% create scatters for different Methods
% rows: methods: 'Original', Low-pass, High-pass
% columns: fast- vs. slow-scale
% i.e., 3x2 figure

labels = {'MSEVanilla'; 'MSEfiltskip'; 'MSEhp'};
scales = {[1:3]; [32:42]};

labelTitle = {'Original'; 'Low-pass'; 'High-pass'};
scaleTitle = {'1-3 (> 50 Hz; Fine)'; '32-42 (< 8 Hz; Coarse)'};

h = figure('units','normalized','position',[.1 .1 .5 .4]);
for indScale = 1:2
    for indMethod = 1:3
        subplot(2,3,(indScale-1)*3+indMethod);
        channels = 43:60; % parieto-occipital channels
        cla; hold on;
        x = squeeze(nanmean(nanmean(mseMerged{1,2}.(labels{indMethod})(idx_YA_mse,channels,scales{indScale}),3),2));
        y = squeeze(nanmean(linFit_2_30_EO(idx_YA_fft, channels),2));
        l1 = scatter(x,y, 50,'filled', 'r'); y1_ls = polyval(polyfit(x,y,1),x); y1_ls = plot(x, y1_ls, 'Color', 'r', 'LineWidth', 3);
        [rl1,pl1] = corrcoef(x,y); pval1 = []; pval1 = convertPtoExponential(pl1(2));
        % add OA
        x = squeeze(nanmean(nanmean(mseMerged{2,2}.(labels{indMethod})(idx_OA_mse,channels,scales{indScale}),3),2));
        y = squeeze(nanmean(linFit_2_30_EO(idx_OA_fft, channels),2));
        l2 = scatter(x,y, 50,'filled', 'k'); y2_ls = polyval(polyfit(x,y,1),x); y2_ls = plot(x, y2_ls, 'Color', 'k', 'LineWidth', 3);
        [rl2,pl2] = corrcoef(x,y); pval2 = []; pval2 = convertPtoExponential(pl2(2));
%         if indMethod == 1 & indScale == 1 || indMethod == 2 & indScale == 1 || indMethod == 3 & indScale == 2
%             loc = 'South';
%         elseif indMethod == 1 & indScale == 2
%             loc = 'South';
%         elseif indMethod == 2 & indScale == 2 || indMethod == 3 & indScale == 1
%             loc = 'South';
%         end
        loc = 'South';
        lgd1 = legend([y1_ls, y2_ls], {['Younger Adults: r=', num2str(round(rl1(2),2)), ', p=',pval1{1}], ...
                ['Older Adults: r=', num2str(round(rl2(2),2)), ', p=',pval2{1}]}, 'Location', loc); legend('boxoff');
        xlabel([labelTitle{indMethod}, ' MSE : Scales ', scaleTitle{indScale}]); 
        if indMethod == 1 
           ylabel('PSD Slope 2-64 Hz (excl. 7-13 Hz)');
        else
            ylabel('PSD Slope');
        end
        title({'Relation between MSE and PSD slopes:'; [labelTitle{indMethod}, ' MSE : Scales ', scaleTitle{indScale}]})
        %xlim([0 1]);
        ylim([-.06, .01])
        yticks([-.04, -.02, 0])
    end
end
set(findall(gcf,'-property','FontSize'),'FontSize',14)

pn.plotFolder = '/Volumes/LNDG/Projects/StateSwitch/dynamic/data/eeg/rest/B_analyses/A_MSE_CSD_multiVariant/C_figures/';
figureName = 'F4_FastScalePSDassociation_byMethod';
saveas(h, [pn.plotFolder, figureName], 'fig');
saveas(h, [pn.plotFolder, figureName], 'epsc');
saveas(h, [pn.plotFolder, figureName], 'png');

