function L_MSE_alphaBandstop(indID, indCond, variant)

%% set up paths

if ismac
    pn.root = '/Users/kosciessa/Desktop/mntTardis/STSWD_Rest/WIP_eeg/';
    pn.tools    = [pn.root, 'A_MSE_CSD_multiVariant/T_tools/'];
    addpath([pn.tools, 'mMSE/']);
    addpath([pn.tools, 'fieldtrip-20170904/']);
    ft_defaults
else
    pn.root = '/home/mpib/kosciessa/STSWD_Rest/WIP_eeg/';
    pn.tools    = [pn.root, 'A_MSE_CSD_multiVariant/T_tools/'];
end
pn.dataIn   = [pn.root, 'A_MSE_CSD_multiVariant/B_data/B_MSE_Segmented_Dim_Input/'];
pn.dataOut  = [pn.root, 'A_MSE_CSD_multiVariant/B_data/C_MSE_Output_alphaBS/']; mkdir(pn.dataOut);

%% select data

cfg.ID = indID;
cfg.cond = indCond;
cfg.variant = variant;

load([pn.dataIn, sprintf('%s_%s_MSE_IN.mat', cfg.ID, cfg.cond)])

%% get IAF from spectrum

cfg_FFT              = [];
cfg_FFT.output       = 'pow';
cfg_FFT.channel      = 'all';
cfg_FFT.method       = 'mtmfft';
cfg_FFT.taper        = 'hanning';
cfg_FFT.keeptrials   = 'no';
cfg_FFT.pad          = ceil(size(data.time,2)/10)*25; % padding in s, such that cfg.foi/T is integer
cfg_FFT.foi          = 8:.01:15;

fftdata = ft_freqanalysis(cfg_FFT, data);

[~, idxMax] = max(nanmean(fftdata.powspctrm(58:60,:),1));

IAF = cfg_FFT.foi(idxMax);

%% bandstop filter on alpha band

%dataOrig = data;

cfg_BS = [];
cfg_BS.bsfilter = 'yes';
cfg_BS.bsfreq = [IAF-3 IAF+3];
cfg_BS.bsfiltord = 3;
cfg_BS.bpfilttype = 'but';
data = ft_preprocessing(cfg_BS, data);

% figure; hold on;
% plot(dataOrig.trial{1}(30,:))
% plot(data.trial{1}(30,:))
% 
% figure; hold on;
% plot(dataOrig.trial{1}(59,:))
% plot(data.trial{1}(59,:))

%% setup mMSE
% artificial trials have been created from -1.5 to 1.5

cfg.toi                 = 0; % across extended periods
cfg.timwin              = 2.9;
cfg.timescales          = [1:42]; % scale list
cfg.m                   = 2; % pattern length
cfg.r                   = 0.5; % similarity criterion
if strcmp(variant, 'hp')
    cfg.coarsegrainmethod = 'filtskip';
    cfg.filtmethod = 'hp';
    cfg.recompute_r  = 'perscale_toi_sp';
elseif strcmp(variant, 'bp')
    cfg.coarsegrainmethod = 'filtskip';
    cfg.filtmethod = 'bp';
    cfg.recompute_r  = 'perscale_toi_sp';
elseif strcmp(variant, 'filtskip')
    cfg.coarsegrainmethod = 'filtskip';
    cfg.filtmethod = 'lp';
    cfg.recompute_r  = 'perscale_toi_sp';
elseif strcmp(variant, 'pointavg')
    cfg.coarsegrainmethod = 'pointavg';
    cfg.filtmethod = 'no';
    cfg.recompute_r  = 'perscale_toi_sp';
elseif strcmp(variant, 'vanilla')
    cfg.coarsegrainmethod = 'pointavg';
    cfg.filtmethod = 'no';
    cfg.recompute_r  = 'per_toi';
end

mse = ft_entropyanalysis(cfg, data);

%% save output

save([pn.dataOut, sprintf('%s_%s_MSE_OUT_%s.mat', cfg.ID, cfg.cond, cfg.variant)], 'mse', 'cfg')

end
